%global _hardened_build 1
%global majorversion    9.4
%global minorversion    0
%global toolsbuild      1280544
%global toolsversion    %{majorversion}.%{minorversion}
%global toolsdaemon     vmtoolsd

Name:             open-vm-tools
Version:          %{toolsversion}
Release:          1%{?dist}
Summary:          Open VMware Tools for virtual machines hosted on VMware
Group:            Applications/System
License:          GPLv2
URL:              http://%{name}.sourceforge.net/
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
ExclusiveArch:    %{ix86} x86_64

Source0:          http://sourceforge.net/projects/%{name}/files/%{name}/stable-%{majorversion}.x/%{name}-%{version}-%{toolsbuild}.tar.gz
Source1:          %{toolsdaemon}.service
Source2:          %{toolsdaemon}.init

BuildRequires:          gcc-c++
BuildRequires:          doxygen
# Fuse is optional and enables vmblock-fuse
BuildRequires:          fuse-devel
BuildRequires:          glib2-devel >= 2.6.0
BuildRequires:          gtk2-devel >= 2.4.0
BuildRequires:          gtkmm24-devel
BuildRequires:          libdnet-devel
BuildRequires:          libicu-devel
BuildRequires:          libX11-devel
BuildRequires:          libXext-devel
BuildRequires:          libXi-devel
BuildRequires:          libXinerama-devel
BuildRequires:          libXrandr-devel
BuildRequires:          libXrender-devel
BuildRequires:          libXtst-devel
BuildRequires:          pam-devel

%if 0%{?rhel} == 6
BuildRequires:          procps
%else
BuildRequires:          procps-devel
%endif

%if 0%{?fedora} || 0%{?rhel} >= 7
BuildRequires:          systemd
Requires(post):         systemd
Requires(preun):        systemd
Requires(postun):       systemd
%endif

%if 0%{?rhel} == 5 || 0%{?rhel} == 6
Requires(post):         /sbin/chkconfig
Requires(preun):        /sbin/chkconfig
Requires(preun):        /sbin/service
Requires(postun):       /sbin/service
%endif

%description
The %{name} project is an open source implementation of VMware Tools. It
is a suite of open source virtualization utilities and drivers to improve the
functionality, user experience and administration of VMware virtual machines.
This package contains only the core user-space programs and libraries of
%{name}.

%package          desktop
Summary:          User experience components for Open VMware Tools
Group:            System Environment/Libraries
Requires:         %{name}%{?_isa} = %{version}-%{release}

%description      desktop
This package contains only the user-space programs and libraries of
%{name} that are essential for improved user experience of VMware virtual
machines.

%package          devel
Summary:          Development libraries for Open VMware Tools
Group:            Development/Libraries
Requires:         %{name}%{?_isa} = %{version}-%{release}

%description      devel
This package contains only the user-space programs and libraries of
%{name} that are essential for developing customized applications for
VMware virtual machines.

%prep
%setup -q -n %{name}-%{version}-%{toolsbuild}

%build
# Use -Wno-unused-local-typedefs to build with GCC 4.8
# Use -Wno-deprecated-declarations for version 9.4.0
export CFLAGS="$RPM_OPT_FLAGS -Wno-unused-local-typedefs -Wno-deprecated-declarations"
export CXXLAGS="$RPM_OPT_FLAGS -Wno-unused-local-typedefs -Wno-deprecated-declarations"
# Required for version 9.4.0
export CUSTOM_PROCPS_NAME=procps
%configure \
    --without-kernel-modules \
    --disable-static
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
make %{?_smp_mflags}

%install
export DONT_STRIP=1
make install DESTDIR=%{buildroot}

# Remove exec bit from config files
chmod a-x %{buildroot}%{_sysconfdir}/pam.d/*

# Remove the DOS line endings
sed -i "s|\r||g" README

# Remove "Encoding" key from the "Desktop Entry"
sed -i "s|^Encoding.*$||g" %{buildroot}%{_sysconfdir}/xdg/autostart/vmware-user.desktop

# Remove unnecessary files from packaging
find %{buildroot}%{_libdir} -name '*.la' -delete
rm -fr %{buildroot}%{_defaultdocdir}
rm -f docs/api/build/html/FreeSans.ttf

%if 0%{?fedora} || 0%{?rhel} >= 7

# Systemd unit files
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_unitdir}/%{toolsdaemon}.service

%else

# Initscripts
install -p -m 755 -D %{SOURCE2} %{buildroot}%{_initrddir}/%{toolsdaemon}

%endif

# 'make check' in open-vm-tools rebuilds docs and ends up regenerating
# the font file. We can add %%check secion once 'make check' is fixed
# upstream

%if 0%{?fedora} || 0%{?rhel} >= 7

%post
/sbin/ldconfig
%systemd_post %{toolsdaemon}.service

%preun
%systemd_preun %{toolsdaemon}.service

%postun
/sbin/ldconfig
%systemd_postun_with_restart %{toolsdaemon}.service

%endif

%if 0%{?rhel} == 6 || 0%{?rhel} == 5

%post
/sbin/ldconfig
/sbin/chkconfig --add %{toolsdaemon}

%preun
if [ $1 -eq 0 ]; then
    /sbin/service %{toolsdaemon} stop >/dev/null 2>&1 || :
    /sbin/chkconfig --del %{toolsdaemon}
fi

%postun
/sbin/ldconfig
if [ $1 -ge 1 ]; then
    /sbin/service %{toolsdaemon} condrestart >/dev/null 2>&1 || :
fi

%endif

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README
%config(noreplace) %{_sysconfdir}/pam.d/*
%{_sysconfdir}/vmware-tools/
%{_bindir}/vmtoolsd
%{_bindir}/vmware-checkvm
%{_bindir}/vmware-hgfsclient
%{_bindir}/vmware-rpctool
%{_bindir}/vmware-toolbox-cmd
%{_bindir}/vmware-xferlogs
%{_libdir}/libguestlib.so.*
%{_libdir}/libhgfs.so.*
%{_libdir}/libvmtools.so.*
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/common
%{_libdir}/%{name}/plugins/common/*.so
%dir %{_libdir}/%{name}/plugins/vmsvc
%{_libdir}/%{name}/plugins/vmsvc/*.so
%exclude %{_sbindir}/mount.vmhgfs
%{_datadir}/%{name}/
%exclude /sbin/
%if 0%{?fedora} || 0%{?rhel} >= 7
%{_unitdir}/%{toolsdaemon}.service
%else
%{_initrddir}/%{toolsdaemon}
%endif

%files desktop
%defattr(-,root,root,-)
%{_sysconfdir}/xdg/autostart/*.desktop
%{_bindir}/vmware-user-suid-wrapper
%{_bindir}/vmware-vmblock-fuse
%{_libdir}/%{name}/plugins/vmusr/

%files devel
%defattr(-,root,root,-)
%doc docs/api/build/*
%{_includedir}/vmGuestLib/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libguestlib.so
%{_libdir}/libhgfs.so
%{_libdir}/libvmtools.so

%changelog
* Wed Nov 13 2013 Ravindra Kumar <ravindrakumar@vmware.com> - 9.4.0-1
- Package new upstream version open-vm-tools-9.4.0-1280544.
- Added CUSTOM_PROCPS_NAME=procps and -Wno-deprecated-declarations
  for version 9.4.0.

* Fri Aug 09 2013 Simone Caronni <negativo17@gmail.com> - 9.2.3-7
- Added options for hardening build (bug 990549).
- Excluded unwanted file mount.vmhgfs from packaging (bug 990547).
- Removed deprecated key "Encoding" from "Desktop Entry" (bug 990552).
- Removed Fedora 17 support (EOL).

* Tue Jun 04 2013 Richard W.M. Jones <rjones@redhat.com> - 9.2.3-6
- Add BR gcc-c++.

* Fri May 03 2013 Simone Caronni <negativo17@gmail.com> - 9.2.3-5
- Add missing ldconfig to SysV targets.

* Thu May 02 2013 Simone Caronni <negativo17@gmail.com> - 9.2.3-4
- Remove restart directive from service file.

* Tue Apr 30 2013 Simone Caronni <negativo17@gmail.com> - 9.2.3-3
- Require glib >= 2.14.0.
- Change service restart policy.

* Fri Apr 26 2013 Simone Caronni <negativo17@gmail.com> - 9.2.3-2
- Enable service by default on systemd systems.

* Fri Apr 26 2013 Simone Caronni <negativo17@gmail.com> - 9.2.3-1
- Package new upstream version open-vm-tools-9.2.3-1031360.
- Removed configure options CUSTOM_PROCPS_NAME (for libproc) and
  -Wno-deprecated-declarations as these have been addressed in
  open-vm-tools-9.2.3-1031360.
- Added workaround for RHEL bug #950748.

* Wed Apr 24 2013 Simone Caronni <negativo17@gmail.com> - 9.2.2-1
- First build.
